import { aws_lambda as lambda } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { BaseDependencyPackager, DependencyPackagerProps, LayerProps } from './base';
/**
 * Packager for creating Lambda layers for Node.js dependencies in AWS. Nothing is done locally so this doesn't require Docker, doesn't download any packages and doesn't upload huge files to S3.
 */
export declare class NodejsDependencyPackager extends BaseDependencyPackager {
    private static runtimeVersion;
    constructor(scope: Construct, id: string, props?: DependencyPackagerProps);
    /**
     * Create a layer for dependencies passed as an argument and installed with npm.
     */
    layerFromInline(id: string, libraries: string[], props?: LayerProps): lambda.LayerVersion;
    /**
     * Create a layer for dependencies defined in package.json and (optionally) package-lock.json and installed with npm.
     */
    layerFromPackageJson(id: string, path: string, props?: LayerProps): lambda.LayerVersion;
    /**
     * Create a layer for dependencies defined in package.json and yarn.lock and installed with yarn.
     */
    layerFromYarn(id: string, path: string, props?: LayerProps): lambda.LayerVersion;
}
