import { aws_lambda as lambda } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { BaseDependencyPackager, DependencyPackagerProps, LayerProps } from './base';
/**
 * Packager for creating Lambda layers for Python dependencies in AWS. Nothing is done locally so this doesn't require Docker, doesn't download any packages and doesn't upload huge files to S3.
 */
export declare class PythonDependencyPackager extends BaseDependencyPackager {
    private static runtimeVersion;
    constructor(scope: Construct, id: string, props?: DependencyPackagerProps);
    /**
     * Create a layer for dependencies passed as an argument and installed with pip.
     */
    layerFromInline(id: string, requirements: string[], props?: LayerProps): lambda.LayerVersion;
    /**
     * Create a layer for dependencies defined in requirements.txt and installed with pip.
     */
    layerFromRequirementsTxt(id: string, path: string, props?: LayerProps): lambda.LayerVersion;
    /**
     * Create a layer for dependencies defined in Pipfile and (optionally) Pipfile.lock and installed with pipenv.
     */
    layerFromPipenv(id: string, path: string, props?: LayerProps): lambda.LayerVersion;
    /**
     * Create a layer for dependencies defined in pyproject.toml and (optionally) poetry.lock and installed with poetry.
     */
    layerFromPoetry(id: string, path: string, props?: LayerProps): lambda.LayerVersion;
}
